## OpenGen

Code generation tool for OpEn

### Installation 
To use this Python package, run:

```
pip install opengen
```

You will then be able to use it in your project with

```python
from opengen import *
```

or 

```python
import opengen as og
```

In order to build the auto-generated code, you need the 
Rust compiler.

For detailed documentation, please refer to 
[OpEn's website](https://alphaville.github.io/optimization-engine/).

## Citing OpEn

Please, cite OpEn as follows:

```
@inproceedings{open2020,
author="P. Sopasakis and E. Fresk and P. Patrinos",
title="OpEn: Code Generation for Embedded Nonconvex Optimization",
booktitle="IFAC World Congress",
year="2020",
address="Berlin"
}
```
 